Wholesale Beads and Jewelry Making Supplies - Fire Mountain Gems and Beads
Description: America's favorite beads and beading supplies since 1973. Largest selection of beads and jewelry making supplies at wholesale prices.

- 800-355-2137

- Login
- Create Account
- Favorites List

Close
Email:
Password:
Remember Me
Forgot Your Password? Need Help?
? If you are still having trouble signing in, click here.
0 items
Home
Deal of the Day FREE Catalog

# Customers of America's favorite beading and jewelry supply company say:

"You guys ROCK!!! You have the best selection and prices anywhere. Believe me...I have looked around. Thanks for all that you do."

- Melissa

## NEW & Hot Products

Swarovski® crystal Pavé Edelweiss & Infinity Charms
Gift Boxes with Shimmery Ribbons and Bows
Over 80 New Jewelry Selections

## Resources

- Get fresh ideas from thousands of fashionable jewelry pieces.
- Look over necklaces, bracelets and earring designs.

Go
Go

- Get FREE beading patterns.
- Discover new techniques.
- Learn all you need to know about designing with Swarovski® crystal components.

Go
Go

- Useful charts and interesting articles.
- Answers to your jewelry-making questions.
- Complete dictionary of beading terms.
- Everything you ever wanted to know about gemstones.

Go

Q.

I am very interested in learning more about your Hemalyke™ and how it is produced. I will be sending a large order very soon for the magnetized Hemalyke. I need to know more information since I'll be making and selling jewelry containing your trademarked

  A. Read the Answer

Have a Jewelry-Making Question? Submit your question to the leading industry experts or search previously answered questions. These questions include jewelry-making techniques, business and marketing, ergonomic solutions and more.

Ask a Question

## What’s Happening!

The votes are in and the results are here. Amanda Bielski-Wright has taken home the Grand Prize Gold Medal Prize for her unbelievably detailed, Eastern influenced necklace and earring set Long Life and Compassion. Help us congratulate her and the other amazingly talented designer-artists of the 2015 Creative Clays Contest by viewing all the winning pieces.

Submit your Metal Contest entry for a chance to be our next Grand Prize Gold Winner. Designs, with any combination of at least 50% Metal Clay, metal beads, wire, chain, jumprings or findings available at Fire Mountain Gems, need to be entered by 1/31/2016. Earn a $1,000 gift certificate, worldwide exposure as a recognized designer-artist and more. Don't delay, enter today!

## Jewelry Maker’s Catalogs

### Free Catalog

- Best selling jewelry-making products
- Inspirational design ideas to get you started

Order Here

### Free Comprehensive Catalog

- 1,254 pages full of jewelry-making supplies
- NEW inspirational design ideas
- Widest selection anywhere with over 40,000 jewelry-making products!
- FREE to all U.S. customers who have placed orders over $150 in the past 12 months. $200 for International customers.

#### Sign up for Email Offers

- New Product Announcements
- Sale Announcements
- Beading News and More...

Get Today's Deal!